/** \file
*/

#ifndef TIMER_H
#define TIMER_H

#include "board.h"

/** \note
	Frequency Output Range vs. selected ration on Master Clock \n
    Reminder: The master clock frequency is 47.9232 MHz on the AT91SAM7S \n
    With Master clock /2 (TCCLKS = 0) we can switch between 365.625 Hz up to 23.9616 MHz \n
    With Master clock /8 (TCCLKS = 1) we can switch between 91.40625 Hz up to 5.9904 MHz \n
    With Master clock /32 (TCCLKS = 2) we can switch between  22.8515.. Hz up to 1.4976 MHz \n
    With Master clock /128 (TCCLKS = 3) we can switch between 5.71289 Hz up to 374.4 kHz \n
    With Master clock /1024 (TCCLKS = 4) we can switch between 0.71411... Hz up to 46800 Hz \n
*/

#define TIMER_ID                  12    ///< Timer used by ADC: Timer 0 (Timer 1 is 13, Timer 2 is 14)

/** \brief Select the ratio between master clock and the timer clock. According to this choice,
	you have to modify TIMER_VALUE definition below
*/
#define   TC_MCK_DIV            0   

/** Selects the sampling frequency in hertz. This choice has to be in accordance with
	the selected Frequency Output Range defined by the TC_MCK_DIV ratio
*/
extern unsigned int SAMPLING_FREQUENCY;

/** \brief You have to capture in this formula, 2, 8, 32, 128 or 1024 according to TC_MCK_DIV */
#define   TIMER_VALUE            (MCK/(2*SAMPLING_FREQUENCY))

/** \brief Pulse duration in term of Timer Clock Cycle(s) */
#define   PULSEWIDTH  5             


/** \brief Configure timer
    \param TC_pt 		T/C	pointer
    \param Mode 		running mode
    \param TimerId 		timer ID
*/
void AT91F_TC_Open (AT91PS_TC TC_pt, unsigned int Mode, unsigned int TimerId);

#endif
